@@ -12,6 +12,7 @@ import xarray as xr
 import nowcasting_dataset.time as nd_time
 from nowcasting_dataset import square
 from nowcasting_dataset.data_sources.datasource_output import DataSourceOutput
+from nowcasting_dataset.dataset.xr_utils import join_dataset_to_batch_dataset
 
 logger = logging.getLogger(__name__)
 
@@ -122,16 +123,19 @@ class DataSource:
         examples = []
         zipped = zip(t0_datetimes, x_locations, y_locations)
         for t0_datetime, x_location, y_location in zipped:
-            output: DataSourceOutput = self.get_example(t0_datetime, x_location, y_location)
+            output: xr.Dataset = self.get_example(t0_datetime, x_location, y_location)
 
-            if self.convert_to_numpy:
-                output.to_numpy()
             examples.append(output)
 
         # could add option here, to save each data source using
         # 1. # DataSourceOutput.to_xr_dataset() to make it a dataset
         # 2. DataSourceOutput.save_netcdf(), save to netcdf
-        return DataSourceOutput.create_batch_from_examples(examples)
+
+        # get the name of the cls, this could be one of the data sources like Sun
+        cls = examples[0].__class__
+
+        # join the examples together, and cast them to the cls, so that validation can occur
+        return cls(join_dataset_to_batch_dataset(examples))
 
     def datetime_index(self) -> pd.DatetimeIndex:
         """Returns a complete list of all available datetimes."""
@@ -203,7 +207,7 @@ class DataSource:
         t0_dt: pd.Timestamp,  #: Datetime of "now": The most recent obs.
         x_meters_center: Number,  #: Centre, in OSGB coordinates.
         y_meters_center: Number,  #: Centre, in OSGB coordinates.
-    ) -> DataSourceOutput:
+    ) -> xr.Dataset:
         """Must be overridden by child classes."""
         raise NotImplementedError()
 
@@ -305,7 +309,10 @@ class ZarrDataSource(ImageDataSource):
                 f"actual shape {selected_data.shape}"
             )
 
-        return self._put_data_into_example(selected_data)
+        # rename 'variable' to 'channels'
+        selected_data = selected_data.rename({"variable": "channels"})
+
+        return selected_data
 
     def geospatial_border(self) -> List[Tuple[Number, Number]]:
         """
@@ -342,6 +349,3 @@ class ZarrDataSource(ImageDataSource):
 
     def _open_data(self) -> xr.DataArray:
         raise NotImplementedError()
-
-    def _put_data_into_example(self, selected_data: xr.DataArray) -> DataSourceOutput:
-        raise NotImplementedError()
